@@ -99,6 +99,12 @@ class TestExternalConfig(unittest.TestCase):
         ec.connection_id = "path/to/connection"
         self.assertEqual(ec.connection_id, "path/to/connection")
 
+    def test_reference_file_schema_uri(self):
+        ec = external_config.ExternalConfig("")
+        self.assertIsNone(ec.reference_file_schema_uri)
+        ec.reference_file_schema_uri = "path/to/reference"
+        self.assertEqual(ec.reference_file_schema_uri, "path/to/reference")
+
     def test_schema_None(self):
         ec = external_config.ExternalConfig("")
         ec.schema = None
